pub struct AvailableLanguageRequest {
pub model: String,
}Expand description
Returns a map of model names to its source and target language pairs. Can specificy a specific model name to retrieve only its language pairs.
Fields
model: StringIf empty returns all available languages.